module Config.Pages.Home.Helpers exposing (..)

import Config.Data.Identity exposing (pageNames)
import Config.Helpers.Format
    exposing
        ( paragraphFontSize
        , paragraphSpacing
        )
import Config.Helpers.Response exposing (topLevelContainer)
import Config.Helpers.Viewport exposing (resetViewport)
import Config.Pages.HyperBlog.Helpers exposing (..)
import Config.Style.Colour exposing (colourTheme)
import Config.Style.Glow exposing (glowDeepDarkGrey)
import Config.Style.Icons.Icons
    exposing
        ( upRootLarge
        , upRootMedium
        , upRootSmall
        )
import Element as E exposing (..)
import Element.Background as B
import Element.Border as D
import Element.Font as F
import Html exposing (Html)
import Html.Attributes as H


homePage : Html msg -> Element msg
homePage image =
    column
        [ centerX
        , centerY
        , spacing 20
        ]
        [ el [ centerX, E.width fill, height <| px 100 ] <|
            html image
        , column
            [ paddingEach
                { top = 15
                , bottom = 15
                , left = 20
                , right = 20
                }
            , glowDeepDarkGrey
            , B.color colourTheme.backgroundDarkGrey
            , D.rounded 10
            , E.width fill
            , spacing 8
            ]
            [ paragraph
                ([ F.color colourTheme.textLightGrey
                 , paragraphSpacing
                 , paragraphFontSize
                 ]
                    ++ [ centerX ]
                )
                [ text "upRootNutrition is an open source project, created by Nick Hiebert, designed to elevate the quality of nutrition science communication in online discourse. By applying more rigorous systems of reasoning, such as formal logic, upRootNutrition aims to cut through the misinformation and sophistry that are endemic on social media." ]
            ]
        ]


desktopHomePageImage : Html msg
desktopHomePageImage =
    upRootLarge


mobileLargeHomePageImage : Html msg
mobileLargeHomePageImage =
    upRootMedium


mobileSmallHomePageImage : Html msg
mobileSmallHomePageImage =
    upRootSmall


desktopHomePage =
    homePage desktopHomePageImage


mobileLargeHomePage =
    homePage mobileLargeHomePageImage


mobileSmallHomePage =
    homePage mobileSmallHomePageImage
