module Config.Pages.Services.Helpers exposing (..)

import Browser
import Config.Helpers.CardFormat exposing (..)
import Config.Helpers.Format
    exposing
        ( paragraphFontSize
        , paragraphSpacing
        )
import Config.Pages.Services.Types exposing (..)
import Config.Style.Colour exposing (colourTheme)
import Element as E exposing (..)
import Element.Background as B
import Element.Border as D
import Element.Font as F


serviceMaker : Service msg -> Element msg
serviceMaker service =
    row
        topLevelBox
        [ desktopCardMaker desktopImageBoxSize desktopImageSize (serviceImage service) service.serviceLink
        , cardMaker
            [ cardTitleMaker service.serviceName
            , cardFormatter
                [ cardContentSpacing
                    [ column
                        fieldSpacer
                        [ rateMaker service
                        , descriptionMaker service
                        , offeringMaker service
                        ]
                    ]
                ]
            ]
        ]


serviceMakerMobile : Service msg -> Element msg
serviceMakerMobile service =
    row
        topLevelBox
        [ column [] []
        , cardMaker
            [ cardTitleMaker service.serviceName
            , cardFormatter
                [ cardContentSpacing
                    [ column
                        fieldSpacer
                        [ row [ spacing 10 ] [ mobileCardMaker mobileImageBoxSize mobileImageSize (serviceImage service) service.serviceLink, rateMaker service ]
                        , descriptionMaker service
                        , offeringMaker service
                        ]
                    ]
                ]
            ]
        ]


serviceImage : Service msg -> { src : String, description : String }
serviceImage service =
    { src = "services/" ++ service.serviceImage ++ ".png"
    , description = service.serviceName
    }


serviceWidth =
    width <| px 45


rateMaker : Service msg -> Element msg
rateMaker service =
    row
        ([ F.color colourTheme.textLightGrey
         , paragraphSpacing
         , paragraphFontSize
         , F.bold
         ]
            ++ [ F.size 18
               , E.width fill
               ]
        )
        [ column
            [ alignTop
            , serviceWidth
            ]
            [ E.text "Rate:"
            ]
        , column
            [ E.width fill
            , alignLeft
            ]
            [ paragraph [ F.regular ]
                [ el [ F.color colourTheme.textLightOrange ] <|
                    E.text service.serviceRate
                ]
            ]
        ]


descriptionMaker : Service msg -> Element msg
descriptionMaker service =
    row
        [ F.color colourTheme.textLightGrey
        , paragraphSpacing
        , paragraphFontSize
        , F.bold
        ]
        [ column
            [ alignTop
            , width <| px 80
            ]
            [ E.text "Offerings:"
            ]
        ]


offeringMaker : Service msg -> Element msg
offeringMaker service =
    column
        [ spacing 8
        , width fill
        , paddingEach
            { top = 0
            , right = 0
            , bottom = 0
            , left = 35
            }
        ]
    <|
        List.map2 (\x y -> makeDescription x)
            service.serviceDescription
            (List.range 1 (List.length service.serviceDescription))


makeDescription : Description -> Element msg
makeDescription description =
    column
        ([ F.color colourTheme.textLightGrey
         , paragraphSpacing
         , paragraphFontSize
         , F.bold
         , alignLeft
         ]
            ++ [ spacing 8
               , width fill
               ]
        )
        [ paragraph [ F.regular ]
            [ E.text ("‣ " ++ description.point) ]
        ]
