module Pages.Debate exposing (Model, Msg, page)

import Config.Data.Identity exposing (pageNames)
import Config.Helpers.Response
    exposing
        ( pageList
        , topLevelContainer
        
        )
import Config.Helpers.Viewport exposing (resetViewport)
import Config.Pages.Debate.Debate.Helpers exposing (..)
import Config.Pages.Debate.Debate.Pages.Arguments exposing (debateArguments)
import Config.Pages.Debate.Debate.Pages.Cucklist exposing (debateCuckList)
import Config.Pages.Debate.Debate.Pages.Gibberish exposing (debateGibberish)
import Config.Pages.Headers.Helpers exposing (headerMaker)
import Config.Pages.Headers.Pages.Debate exposing (debateHeader)
import Config.Style.Colour as T exposing (colourTheme)
import Effect exposing (Effect)
import Element as E exposing (..)
import Layouts
import Page exposing (Page)
import Route exposing (Route)
import Shared exposing (..)
import Task
import View exposing (View)


page : Shared.Model -> Route () -> Page Model Msg
page shared route =
    Page.new
        { init = init
        , update = update
        , subscriptions = subscriptions
        , view = view shared
        }
        |> Page.withLayout toLayout


toLayout : Model -> Layouts.Layout Msg
toLayout model =
    Layouts.Navbar {}



-- INIT


type alias Model =
    {}


init : () -> ( Model, Effect Msg )
init () =
    ( {}
    , Effect.none
    )



-- UPDATE


type Msg
    = NoOp


update : Msg -> Model -> ( Model, Effect Msg )
update msg model =
    case msg of
        NoOp ->
            ( model
            , Effect.none
            )



-- SUBSCRIPTIONS


subscriptions : Model -> Sub Msg
subscriptions model =
    Sub.none



-- VIEW


view : Shared.Model -> Model -> View Msg
view shared model =
    { title = pageNames.pageDebate
    , attributes = []
    , element = debateContainer shared.device
    }


debateContainer : Device -> Element msg
debateContainer device =
    topLevelContainer (debateList device)


debateList : Device -> Element msg
debateList device =
    column
        (case ( device.class, device.orientation ) of
            _ ->
                pageList
        )
    <|
        List.concat
            [ List.map headerMaker
                [ debateHeader ]
            , (case ( device.class, device.orientation ) of
                ( Phone, Portrait ) ->
                    List.map mobileDebateMaker

                ( Tablet, Portrait ) ->
                    List.map mobileDebateMaker

                _ ->
                    List.map desktopDebateMaker
              )
                [ debateArguments
                , debateCuckList
                , debateGibberish
                ]
            ]
