module Pages.Donate exposing (Model, Msg, page)

import Config.Data.Identity as I exposing (..)
import Config.Helpers.Response
    exposing
        ( pageList
        , topLevelContainer
        )
import Config.Helpers.Viewport exposing (..)
import Config.Pages.Donate.Helpers exposing (..)
import Config.Pages.Donate.Methods.Cardano exposing (donateCardano)
import Config.Pages.Donate.Methods.KoFi exposing (donateKoFi)
import Config.Pages.Donate.Methods.LiberaPay exposing (donateLiberaPay)
import Config.Pages.Donate.Methods.Merch exposing (donateMerch)
import Config.Pages.Donate.Methods.Patreon exposing (donatePatreon)
import Config.Pages.Donate.Methods.PayPal exposing (donatePayPal)
import Config.Pages.Donate.Methods.Stripe exposing (donateStripe)
import Config.Pages.Donate.Methods.YouTube exposing (donateYouTube)
import Config.Pages.Donate.Types exposing (..)
import Config.Pages.Headers.Helpers exposing (headerMaker)
import Config.Pages.Headers.Pages.Donate exposing (donateHeader)
import Config.Style.Colour as T exposing (..)
import Effect exposing (Effect)
import Element as E exposing (..)
import Layouts
import Page exposing (Page)
import Route exposing (Route)
import Shared exposing (..)
import Task
import View exposing (View)


page : Shared.Model -> Route () -> Page Model Msg
page shared route =
    Page.new
        { init = init
        , update = update
        , subscriptions = subscriptions
        , view = view shared
        }
        |> Page.withLayout toLayout


toLayout : Model -> Layouts.Layout Msg
toLayout model =
    Layouts.Navbar {}



-- INIT


type alias Model =
    {}


init : () -> ( Model, Effect Msg )
init () =
    ( {}
    , Effect.map
        (\_ -> NoOp)
        (Effect.sendCmd resetViewport)
    )



-- UPDATE


type Msg
    = NoOp


update : Msg -> Model -> ( Model, Effect Msg )
update msg model =
    case msg of
        NoOp ->
            ( model
            , Effect.none
            )



-- SUBSCRIPTIONS


subscriptions : Model -> Sub Msg
subscriptions model =
    Sub.none



-- VIEW


view : Shared.Model -> Model -> View Msg
view shared model =
    { title = pageNames.pageDonate
    , attributes = []
    , element = donateContainer shared.device
    }


donateContainer : Device -> Element msg
donateContainer device =
    topLevelContainer (donateList device)


donateList : Device -> Element msg
donateList device =
    column
        (case ( device.class, device.orientation ) of
            _ ->
                pageList
        )
    <|
        List.concat
            [ List.map headerMaker
                [ donateHeader ]
            , (case ( device.class, device.orientation ) of
                ( Phone, Portrait ) ->
                    List.map donateMakerMobile

                ( Tablet, Portrait ) ->
                    List.map donateMakerMobile

                _ ->
                    List.map donateMaker
              )
                [ donateLiberaPay
                , donateStripe
                , donatePatreon
                , donateCardano
                , donateKoFi
                , donateYouTube
                , donateMerch
                ]
            ]
