module Config.Pages.Debate.Arguments.Inferences.PollinationReductio exposing (..)

import Config.Pages.Debate.Arguments.Types exposing (..)


argumentPollinationReductio : Argument
argumentPollinationReductio =
    { argumentTitle = "Vegan Anti-Pollination Reductio"
    , propositionTitle = "Apples are not vegan"
    , propositionReductio = "Some vegans hold to a deontic principle that any form of animal exploitation is wrong, and the products of exploitation are to be boycotted and designated non-vegan."
    , propositionSummary = "If one accepts that no animal exploitation is permissible, they're committed to some truly hilarious positions, such as apples not being vegan because we exploit the natural behaviour of bees to pollinate our apple trees."
    , proofLink = "https://www.umsu.de/trees/#(~6x(Px~4~3Qx)),(Qb),(~3Pb~5~6y(~3Ry))|=(~3Ra)"
    , argumentCertainty = 10
    , argumentImage = "pollinationreductio"
    , argumentHashtags = []
    , definitionTable =
        [ { definiendum = "P(x)"
          , definiens = "(x) is vegan"
          }
        , { definiendum = "Q(x)"
          , definiens = "(x) involves human on non-human animal exploitation"
          }
        , { definiendum = "R(y)"
          , definiens = "(y) generated are vegan"
          }
        , { definiendum = "x"
          , definiens = "a being"
          }
        , { definiendum = "y"
          , definiens = "a product"
          }
        , { definiendum = "b"
          , definiens = "bees pollinating human crops"
          }
        , { definiendum = "a"
          , definiens = "apples"
          }
        ]
    , argumentFormalization =
        [ { premises =
                [ { premise = "Something is vegan if, and only if, something does not involve human on non-human animal exploitation."
                  , notation = "∀x(Px↔¬Qx)"
                  }
                , { premise = "Bees pollinating human crops involves human on non-human exploitation."
                  , notation = "Qb"
                  }
                , { premise = "If bees pollinating human crops is not vegan, then the products generated are not vegan."
                  , notation = "¬Pb→∀y(¬Ry)"
                  }
                ]
          , conclusion = "Therefore, apples are not vegan."
          , conclusionNotation = "¬Ra"
          }
        ]
    }
